/*
 * $Id$
 *
 * Copyright (C) 2007  Kipp Cannon
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */


#ifndef _TIMESERIES_H
#define _TIMESERIES_H


#include <stddef.h>
#include <lal/LALDatatypes.h>

#include <lal/LALRCSID.h>
NRCSID(TIMESERIESH, "$Id:");



/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyCOMPLEX8TimeSeries (
	COMPLEX8TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
COMPLEX8TimeSeries *XLALCreateCOMPLEX8TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
COMPLEX8TimeSeries *XLALCutCOMPLEX8TimeSeries (
	const COMPLEX8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
COMPLEX8TimeSeries *XLALResizeCOMPLEX8TimeSeries (
	COMPLEX8TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
COMPLEX8TimeSeries *XLALShrinkCOMPLEX8TimeSeries (
	COMPLEX8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddCOMPLEX8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
COMPLEX8TimeSeries *XLALAddCOMPLEX8TimeSeries (
	COMPLEX8TimeSeries *arg1,
	const COMPLEX8TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyCOMPLEX16TimeSeries (
	COMPLEX16TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
COMPLEX16TimeSeries *XLALCreateCOMPLEX16TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
COMPLEX16TimeSeries *XLALCutCOMPLEX16TimeSeries (
	const COMPLEX16TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
COMPLEX16TimeSeries *XLALResizeCOMPLEX16TimeSeries (
	COMPLEX16TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
COMPLEX16TimeSeries *XLALShrinkCOMPLEX16TimeSeries (
	COMPLEX16TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddCOMPLEX16TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
COMPLEX16TimeSeries *XLALAddCOMPLEX16TimeSeries (
	COMPLEX16TimeSeries *arg1,
	const COMPLEX16TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyREAL4TimeSeries (
	REAL4TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
REAL4TimeSeries *XLALCreateREAL4TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
REAL4TimeSeries *XLALCutREAL4TimeSeries (
	const REAL4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
REAL4TimeSeries *XLALResizeREAL4TimeSeries (
	REAL4TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
REAL4TimeSeries *XLALShrinkREAL4TimeSeries (
	REAL4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddREAL4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
REAL4TimeSeries *XLALAddREAL4TimeSeries (
	REAL4TimeSeries *arg1,
	const REAL4TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyREAL8TimeSeries (
	REAL8TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
REAL8TimeSeries *XLALCreateREAL8TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
REAL8TimeSeries *XLALCutREAL8TimeSeries (
	const REAL8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
REAL8TimeSeries *XLALResizeREAL8TimeSeries (
	REAL8TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
REAL8TimeSeries *XLALShrinkREAL8TimeSeries (
	REAL8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddREAL8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
REAL8TimeSeries *XLALAddREAL8TimeSeries (
	REAL8TimeSeries *arg1,
	const REAL8TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyINT2TimeSeries (
	INT2TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
INT2TimeSeries *XLALCreateINT2TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
INT2TimeSeries *XLALCutINT2TimeSeries (
	const INT2TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT2TimeSeries *XLALResizeINT2TimeSeries (
	INT2TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT2TimeSeries *XLALShrinkINT2TimeSeries (
	INT2TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
INT2TimeSeries *XLALAddINT2TimeSeries (
	INT2TimeSeries *arg1,
	const INT2TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyINT4TimeSeries (
	INT4TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
INT4TimeSeries *XLALCreateINT4TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
INT4TimeSeries *XLALCutINT4TimeSeries (
	const INT4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT4TimeSeries *XLALResizeINT4TimeSeries (
	INT4TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT4TimeSeries *XLALShrinkINT4TimeSeries (
	INT4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
INT4TimeSeries *XLALAddINT4TimeSeries (
	INT4TimeSeries *arg1,
	const INT4TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyINT8TimeSeries (
	INT8TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
INT8TimeSeries *XLALCreateINT8TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
INT8TimeSeries *XLALCutINT8TimeSeries (
	const INT8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT8TimeSeries *XLALResizeINT8TimeSeries (
	INT8TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
INT8TimeSeries *XLALShrinkINT8TimeSeries (
	INT8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
INT8TimeSeries *XLALAddINT8TimeSeries (
	INT8TimeSeries *arg1,
	const INT8TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyUINT2TimeSeries (
	UINT2TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
UINT2TimeSeries *XLALCreateUINT2TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
UINT2TimeSeries *XLALCutUINT2TimeSeries (
	const UINT2TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT2TimeSeries *XLALResizeUINT2TimeSeries (
	UINT2TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT2TimeSeries *XLALShrinkUINT2TimeSeries (
	UINT2TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddUINT2TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
UINT2TimeSeries *XLALAddUINT2TimeSeries (
	UINT2TimeSeries *arg1,
	const UINT2TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyUINT4TimeSeries (
	UINT4TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
UINT4TimeSeries *XLALCreateUINT4TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
UINT4TimeSeries *XLALCutUINT4TimeSeries (
	const UINT4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT4TimeSeries *XLALResizeUINT4TimeSeries (
	UINT4TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT4TimeSeries *XLALShrinkUINT4TimeSeries (
	UINT4TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddUINT4TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
UINT4TimeSeries *XLALAddUINT4TimeSeries (
	UINT4TimeSeries *arg1,
	const UINT4TimeSeries *arg2
);
/* </lalVerbatim> */





/* <lalLaTeX file="TimeSeriesDestroyP">
\idx{XLALDestroyUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesDestroyP"> */
void XLALDestroyUINT8TimeSeries (
	UINT8TimeSeries *series
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCreateP">
\idx{XLALCreateUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCreateP"> */
UINT8TimeSeries *XLALCreateUINT8TimeSeries (
	const CHAR *name,
	const LIGOTimeGPS *epoch,
	REAL8 f0,
	REAL8 deltaT,
	const LALUnit *sampleUnits,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesCutP">
\idx{XLALCutUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesCutP"> */
UINT8TimeSeries *XLALCutUINT8TimeSeries (
	const UINT8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALResizeUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT8TimeSeries *XLALResizeUINT8TimeSeries (
	UINT8TimeSeries *series,
	int first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesResizeP">
\idx{XLALShrinkUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesResizeP"> */
UINT8TimeSeries *XLALShrinkUINT8TimeSeries (
	UINT8TimeSeries *series,
	size_t first,
	size_t length
);
/* </lalVerbatim> */

/* <lalLaTeX file="TimeSeriesAddP">
\idx{XLALAddUINT8TimeSeries ()}
</lalLaTeX> <lalVerbatim file="TimeSeriesAddP"> */
UINT8TimeSeries *XLALAddUINT8TimeSeries (
	UINT8TimeSeries *arg1,
	const UINT8TimeSeries *arg2
);
/* </lalVerbatim> */




#endif  /* _TIMESERIES_H */
