/* -*- C -*- */
/******** <lalVerbatim file="VectorIndexRangeHV"> ********
Author: David Chin <dwchin@umich.edu> +1-734-709-9119
$Id$
********* </lalVerbatim> ********/

/**** <lalLaTeX>
 *
 * \section{Header \texttt{VectorIndexRange.h}}
 *
 * Routines to slice up vectors/sequences by
 * specifying starting and ending indices, inclusive.
 * \texttt{VectorIndexHole()}
 * is "complementary" to \texttt{VectorIndexRange()}, in the sense that
 * it returns the two segments of the vector that would remain after
 * \texttt{VectorIndexRange()} acts.
 *
 * \subsection*{Synopsis}
 * \begin{verbatim}
 * #include <lal/VectorIndexRange.h>
 * \end{verbatim}
 *
 * \subsection*{Error conditions}
 * \input{VectorIndexRangeHE}
 *
 * \vfill{\footnotesize\input{VectorIndexRangeHV}}
 * \newpage\input{VectorIndexRangeC}
 *
 ***** </lalLaTeX> */

#include <math.h>
#include <lal/LALRCSID.h>
#include <lal/LALStdlib.h>
#include <lal/SeqFactories.h>
#include <lal/AVFactories.h>

#ifndef __LALVECTORINDEXRANGE_H__
#define __LALVECTORINDEXRANGE_H__

#ifdef __cplusplus
extern "C" {
#endif /* C++ */

NRCSID( VECTORINDEXRANGEH, "$Id$" );

/**** <lalErrTable file="VectorIndexRangeHE"> ****/
#define VECTORINDEXRANGEH_EARG 1
#define VECTORINDEXRANGEH_ECHK 2
#define VECTORINDEXRANGEH_EFLS 3
#define VECTORINDEXRANGEH_EUSE 4
#define VECTORINDEXRANGEH_ENULL 5
#define VECTORINDEXRANGEH_EALOC 6
#define VECTORINDEXRANGEH_EFPMS 7
#define VECTORINDEXRANGEH_ENUMZ 8
#define VECTORINDEXRANGEH_ELNTH 9
#define VECTORINDEXRANGEH_ENNUL 10
#define VECTORINDEXRANGEH_MSGEARG "Error parsing command-line arguments"
#define VECTORINDEXRANGEH_MSGECHK "Error checking failed to catch bad data"
#define VECTORINDEXRANGEH_MSGEFLS "Incorrect answer for valid data"
#define VECTORINDEXRANGEH_MSGEUSE "Bad user-entered data"
#define VECTORINDEXRANGEH_MSGENULL "Null Pointer."
#define VECTORINDEXRANGEH_MSGEALOC "Memory Allocation Error"
#define VECTORINDEXRANGEH_MSGEFPMS "Filter Parameter Structure Error"
#define VECTORINDEXRANGEH_MSGENUMZ "Incorrect number of command line arguments"
#define VECTORINDEXRANGEH_MSGELNTH "Vector/Array of Improper Length"
#define VECTORINDEXRANGEH_MSGENNUL "Non-Null Pointer that should be NULL"
/**** </lalErrTable> ****/

/* typedefs */


/*















*/


typedef struct
tagCHARVectorPair {
  CHARVector **head;
  CHARVector **tail;
} CHARVectorPair;



/*















*/


typedef struct
tagINT2VectorPair {
  INT2Vector **head;
  INT2Vector **tail;
} INT2VectorPair;



/*















*/


typedef struct
tagINT4VectorPair {
  INT4Vector **head;
  INT4Vector **tail;
} INT4VectorPair;



/*















*/


typedef struct
tagINT8VectorPair {
  INT8Vector **head;
  INT8Vector **tail;
} INT8VectorPair;



/*















*/


typedef struct
tagUINT2VectorPair {
  UINT2Vector **head;
  UINT2Vector **tail;
} UINT2VectorPair;



/*















*/


typedef struct
tagUINT4VectorPair {
  UINT4Vector **head;
  UINT4Vector **tail;
} UINT4VectorPair;



/*















*/


typedef struct
tagUINT8VectorPair {
  UINT8Vector **head;
  UINT8Vector **tail;
} UINT8VectorPair;



/*















*/


typedef struct
tagREAL4VectorPair {
  REAL4Vector **head;
  REAL4Vector **tail;
} REAL4VectorPair;



/*















*/


typedef struct
tagREAL8VectorPair {
  REAL8Vector **head;
  REAL8Vector **tail;
} REAL8VectorPair;



/*















*/


typedef struct
tagCOMPLEX8VectorPair {
  COMPLEX8Vector **head;
  COMPLEX8Vector **tail;
} COMPLEX8VectorPair;



/*















*/


typedef struct
tagCOMPLEX16VectorPair {
  COMPLEX16Vector **head;
  COMPLEX16Vector **tail;
} COMPLEX16VectorPair;


/* Function protos */


/*















*/


void LALCHARVectorIndexRange ( LALStatus *status,
          CHARVector    **result,
          CHARVector     *v,
          const UINT4Vector *indexVector );

void LALCHARVectorIndexHole ( LALStatus  *status,
          CHARVectorPair  *result_pair,
          CHARVector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALI2VectorIndexRange ( LALStatus *status,
          INT2Vector    **result,
          INT2Vector     *v,
          const UINT4Vector *indexVector );

void LALI2VectorIndexHole ( LALStatus  *status,
          INT2VectorPair  *result_pair,
          INT2Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALI4VectorIndexRange ( LALStatus *status,
          INT4Vector    **result,
          INT4Vector     *v,
          const UINT4Vector *indexVector );

void LALI4VectorIndexHole ( LALStatus  *status,
          INT4VectorPair  *result_pair,
          INT4Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALI8VectorIndexRange ( LALStatus *status,
          INT8Vector    **result,
          INT8Vector     *v,
          const UINT4Vector *indexVector );

void LALI8VectorIndexHole ( LALStatus  *status,
          INT8VectorPair  *result_pair,
          INT8Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALU2VectorIndexRange ( LALStatus *status,
          UINT2Vector    **result,
          UINT2Vector     *v,
          const UINT4Vector *indexVector );

void LALU2VectorIndexHole ( LALStatus  *status,
          UINT2VectorPair  *result_pair,
          UINT2Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALU4VectorIndexRange ( LALStatus *status,
          UINT4Vector    **result,
          UINT4Vector     *v,
          const UINT4Vector *indexVector );

void LALU4VectorIndexHole ( LALStatus  *status,
          UINT4VectorPair  *result_pair,
          UINT4Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALU8VectorIndexRange ( LALStatus *status,
          UINT8Vector    **result,
          UINT8Vector     *v,
          const UINT4Vector *indexVector );

void LALU8VectorIndexHole ( LALStatus  *status,
          UINT8VectorPair  *result_pair,
          UINT8Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALSVectorIndexRange ( LALStatus *status,
          REAL4Vector    **result,
          REAL4Vector     *v,
          const UINT4Vector *indexVector );

void LALSVectorIndexHole ( LALStatus  *status,
          REAL4VectorPair  *result_pair,
          REAL4Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALDVectorIndexRange ( LALStatus *status,
          REAL8Vector    **result,
          REAL8Vector     *v,
          const UINT4Vector *indexVector );

void LALDVectorIndexHole ( LALStatus  *status,
          REAL8VectorPair  *result_pair,
          REAL8Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALCVectorIndexRange ( LALStatus *status,
          COMPLEX8Vector    **result,
          COMPLEX8Vector     *v,
          const UINT4Vector *indexVector );

void LALCVectorIndexHole ( LALStatus  *status,
          COMPLEX8VectorPair  *result_pair,
          COMPLEX8Vector      *v,
          const UINT4Vector *indexVector );




/*















*/


void LALZVectorIndexRange ( LALStatus *status,
          COMPLEX16Vector    **result,
          COMPLEX16Vector     *v,
          const UINT4Vector *indexVector );

void LALZVectorIndexHole ( LALStatus  *status,
          COMPLEX16VectorPair  *result_pair,
          COMPLEX16Vector      *v,
          const UINT4Vector *indexVector );



#ifdef __cplusplus
}
#endif /* C++ */

#endif /* __LALVECTORINDEXRANGE_H__ */


